@@ -18,12 +18,16 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""CIF (Certificado de Identificación Fiscal, Spanish company tax number).
+"""CIF (Código de Identificación Fiscal, Spanish company tax number).
 
 The CIF is a tax identification number for legal entities. It has 9 digits
 where the first digit is a letter (denoting the type of entity) and the
 last is a check digit (which may also be a letter).
 
+More information
+
+* https://es.wikipedia.org/wiki/Código_de_identificación_fiscal
+
 >>> validate('J99216582')
 'J99216582'
 >>> validate('J99216583')  # invalid check digit
@@ -49,6 +53,7 @@ InvalidFormat: ...
 from stdnum import luhn
 from stdnum.es import dni
 from stdnum.exceptions import *
+from stdnum.util import isdigits
 
 
 __all__ = ['compact', 'validate', 'is_valid', 'split']
@@ -70,7 +75,7 @@ def validate(number):
     """Check if the number provided is a valid DNI number. This checks the
     length, formatting and check digit."""
     number = compact(number)
-    if not number[1:-1].isdigit():
+    if not isdigits(number[1:-1]):
         raise InvalidFormat()
     if len(number) != 9:
         raise InvalidLength()
