@@ -18,7 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""DNI (Documento nacional de identidad, Spanish personal identity codes).
+"""DNI (Documento Nacional de Identidad, Spanish personal identity codes).
 
 The DNI is a 9 digit number used to identify Spanish citizens. The last
 digit is a checksum letter.
@@ -39,7 +39,7 @@ InvalidLength: ...
 """
 
 from stdnum.exceptions import *
-from stdnum.util import clean
+from stdnum.util import clean, isdigits
 
 
 def compact(number):
@@ -55,10 +55,10 @@ def calc_check_digit(number):
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid DNI number. This
-    checks the length, formatting and check digit."""
+    """Check if the number provided is a valid DNI number. This checks the
+    length, formatting and check digit."""
     number = compact(number)
-    if not number[:-1].isdigit():
+    if not isdigits(number[:-1]):
         raise InvalidFormat()
     if len(number) != 9:
         raise InvalidLength()
@@ -68,8 +68,8 @@ def validate(number):
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid DNI number. This
-    checks the length, formatting and check digit."""
+    """Check if the number provided is a valid DNI number. This checks the
+    length, formatting and check digit."""
     try:
         return bool(validate(number))
     except ValidationError:
