@@ -42,6 +42,7 @@ from stdnum.exceptions import *
 from stdnum.iso7064 import mod_97_10
 from stdnum.util import clean
 
+
 # the valid characters we have
 _alphabet = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'
 
@@ -64,7 +65,7 @@ def validate(number):
     number = compact(number)
     try:
         test_number = _to_base10(number)
-    except Exception:
+    except Exception:  # noqa: B902
         raise InvalidFormat()
     # ensure that checksum is valid
     mod_97_10.validate(test_number)
