@@ -31,7 +31,7 @@ InvalidLength: ...
 """
 
 from stdnum.exceptions import *
-from stdnum.util import clean
+from stdnum.util import clean, isdigits
 
 
 def compact(number):
@@ -47,7 +47,7 @@ def validate(number):
     """Check if the number provided is a valid VAT number. This checks the
     length and formatting."""
     number = compact(number)
-    if not number.isdigit():
+    if not isdigits(number):
         raise InvalidFormat()
     if len(number) not in (5, 6):
         raise InvalidLength()
