@@ -1,7 +1,7 @@
 # pvn.py - functions for handling Latvian PVN (VAT) numbers
 # coding: utf-8
 #
-# Copyright (C) 2012-2017 Arthur de Jong
+# Copyright (C) 2012-2019 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -42,7 +42,7 @@ InvalidComponent: ...
 import datetime
 
 from stdnum.exceptions import *
-from stdnum.util import clean
+from stdnum.util import clean, isdigits
 
 
 # validation functions are available on-line but it is not allowed
@@ -70,12 +70,13 @@ def calc_check_digit_pers(number):
     should not have the check digit included."""
     # note that this algorithm has not been confirmed by an independent source
     weights = (10, 5, 8, 4, 2, 1, 6, 3, 7, 9)
-    check = 1 + sum(weights[i] * int(n) for i, n in enumerate(number))
+    check = 1 + sum(w * int(n) for w, n in zip(weights, number))
     return str(check % 11 % 10)
 
 
 def get_birth_date(number):
     """Split the date parts from the number and return the birth date."""
+    number = compact(number)
     day = int(number[0:2])
     month = int(number[2:4])
     year = int(number[4:6])
@@ -90,7 +91,7 @@ def validate(number):
     """Check if the number is a valid VAT number. This checks the length,
     formatting and check digit."""
     number = compact(number)
-    if not number.isdigit():
+    if not isdigits(number):
         raise InvalidFormat()
     if len(number) != 11:
         raise InvalidLength()
