@@ -1,6 +1,6 @@
 # numdb.py - module for handling hierarchically organised numbers
 #
-# Copyright (C) 2010-2021 Arthur de Jong
+# Copyright (C) 2010-2023 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -54,13 +54,13 @@ To split the number and get properties for each part:
 [('98', {'prop1': 'booz'}), ('89', {'prop2': 'foo'})]
 >>> pprint.pprint(dbfile.info('633322'))
 [('6', {'prop1': 'boo'}), ('333', {'prop2': 'bar', 'prop3': 'baz', 'prop4': 'bla'}), ('22', {})]
+>>> pprint.pprint(dbfile.info('1200333'))
+[('1', {'prop1': 'foo'}), ('200', {'prop2': 'bar', 'prop3': 'baz'}), ('333', {'prop4': 'bax'})]
 
 """
 
 import re
 
-from pkg_resources import resource_stream
-
 
 _line_re = re.compile(
     r'^(?P<indent> *)'
@@ -106,7 +106,7 @@ class NumDB():
                     properties = {}
                     next_prefixes = []
                 properties.update(props)
-                next_prefixes.extend(children or [])
+                next_prefixes.extend(children)
         # return first part and recursively find next matches
         return [(part, properties)] + NumDB._find(number[len(part):], next_prefixes)
 
@@ -135,12 +135,13 @@ def _parse(fp):
         indent = len(match.group('indent'))
         ranges = match.group('ranges')
         props = dict(_prop_re.findall(match.group('props')))
+        children = []
         for rnge in ranges.split(','):
             if '-' in rnge:
                 low, high = rnge.split('-')
             else:
                 low, high = rnge, rnge
-            yield indent, len(low), low, high, props
+            yield indent, len(low), low, high, props, children
 
 
 def read(fp):
@@ -148,21 +149,30 @@ def read(fp):
     last_indent = 0
     db = NumDB()
     stack = {0: db.prefixes}
-    for indent, length, low, high, props in _parse(fp):
+    for indent, length, low, high, props, children in _parse(fp):
         if indent > last_indent:
-            # populate the children field of the last indent
-            stack[last_indent][-1][4] = []
+            # set our stack location to the last parent entry
             stack[indent] = stack[last_indent][-1][4]
-        stack[indent].append([length, low, high, props, None])
+        stack[indent].append([length, low, high, props, children])
         last_indent = indent
     return db
 
 
+def _get_resource_stream(name):
+    """Return a readable file-like object for the resource."""
+    try:  # pragma: no cover (Python 3.9 and newer)
+        import importlib.resources
+        return importlib.resources.files(__package__).joinpath(name).open('rb')
+    except (ImportError, AttributeError):  # pragma: no cover (older Python versions)
+        import pkg_resources
+        return pkg_resources.resource_stream(__name__, name)
+
+
 def get(name):
     """Open a database with the specified name to perform queries on."""
     if name not in _open_databases:
         import codecs
         reader = codecs.getreader('utf-8')
-        with reader(resource_stream(__name__, name + '.dat')) as fp:
+        with reader(_get_resource_stream(name + '.dat')) as fp:
             _open_databases[name] = read(fp)
     return _open_databases[name]
