@@ -51,18 +51,15 @@ def compact(number):
 def calc_company_check_digit(number):
     """Calculate the check digit for the 10-digit ИНН for organisations."""
     weights = (2, 4, 10, 3, 5, 9, 4, 6, 8)
-    return str(sum(weights[i] * int(n)
-                   for i, n in enumerate(number[:9])) % 11 % 10)
+    return str(sum(w * int(n) for w, n in zip(weights, number)) % 11 % 10)
 
 
 def calc_personal_check_digits(number):
     """Calculate the check digits for the 12-digit personal ИНН."""
     weights = (7, 2, 4, 10, 3, 5, 9, 4, 6, 8)
-    d1 = str(sum(weights[i] * int(n)
-                 for i, n in enumerate(number[:10])) % 11 % 10)
+    d1 = str(sum(w * int(n) for w, n in zip(weights, number)) % 11 % 10)
     weights = (3, 7, 2, 4, 10, 3, 5, 9, 4, 6, 8)
-    d2 = str(sum(weights[i] * int(n)
-                 for i, n in enumerate(number[:10] + d1)) % 11 % 10)
+    d2 = str(sum(w * int(n) for w, n in zip(weights, number[:10] + d1)) % 11 % 10)
     return d1 + d2
 
 
