@@ -20,7 +20,7 @@
 # 02110-1301 USA
 
 """This script uses introspection to present a list of number formats
-suitable to be included in the README and stdnum package description."""
+suitable to be included in the README.md and stdnum package description."""
 
 import os.path
 import sys
@@ -34,20 +34,20 @@ from stdnum import util  # noqa, isort:skip
 
 
 # these are excluded
-algortihms = (
+algorithms = (
     'stdnum.verhoeff', 'stdnum.luhn', 'stdnum.iso7064', 'stdnum.damm')
 
 
 def get_number_modules():
     """Provide the number modules that are not algorithms."""
     for module in util.get_number_modules():
-        if module.__name__ not in algortihms and \
+        if module.__name__ not in algorithms and \
            not module.__name__.startswith('stdnum.iso7064'):
             yield module
 
 
 if __name__ == '__main__':
-    print('For README:')
+    print('For README.md:')
     print('')
     for module in get_number_modules():
         print(' * %s' % util.get_module_name(module))
